import { Client, Events, GatewayIntentBits, ActivityType } from 'discord.js';
import dotenv from 'dotenv';

// Load environment variables
dotenv.config();

// Create a simplified client with all intents
const client = new Client({
  intents: [
    GatewayIntentBits.Guilds,
    GatewayIntentBits.GuildMessages,
    GatewayIntentBits.MessageContent,
    GatewayIntentBits.GuildVoiceStates,
    GatewayIntentBits.GuildMembers,
    GatewayIntentBits.GuildPresences, // Add this too
  ]
});

// Log detailed info when ready
client.once(Events.ClientReady, (readyClient) => {
  console.log('===========================================');
  console.log(`Logged in as: ${readyClient.user.tag}`);
  console.log(`Bot ID: ${readyClient.user.id}`);
  console.log('===========================================');
  
  // Set a visible activity status
  readyClient.user.setActivity('Joining servers...', { type: ActivityType.Playing });
  
  // Log guild membership
  console.log(`Currently in ${client.guilds.cache.size} guilds:`);
  
  if (client.guilds.cache.size === 0) {
    console.log('Not in any guilds! Please check your invite link.');
    
    // Generate a proper invite link
    const inviteURL = `https://discord.com/api/oauth2/authorize?client_id=${readyClient.user.id}&permissions=3214336&scope=bot%20applications.commands`;
    console.log('\nUse this invite link:');
    console.log(inviteURL);
  } else {
    client.guilds.cache.forEach(guild => {
      console.log(`- ${guild.name} (ID: ${guild.id}) - Members: ${guild.memberCount}`);
    });
  }
});

// Add handler for guild joins to confirm when it works
client.on(Events.GuildCreate, (guild) => {
  console.log(`✅ JOINED GUILD: ${guild.name} (${guild.id})`);
  console.log(`Now in ${client.guilds.cache.size} guilds`);
});

// Log any errors
client.on(Events.Error, (error) => {
  console.error('Discord client error:', error);
});

// Login with token
console.log('Attempting to log in...');
const token = process.env.DISCORD_TOKEN;

if (!token) {
  console.error('ERROR: No Discord token found in .env file');
  process.exit(1);
}

// Show first few characters of token for debugging (never show full token)
console.log(`Using token starting with: ${token.substring(0, 5)}...`);

client.login(token)
  .then(() => console.log('Login successful!'))
  .catch(error => {
    console.error('Failed to log in:', error.message);
    console.error('Please check if your token is valid');
    process.exit(1);
  });
