import { config } from '../config/config';
import { getRandomElement } from './random';
import fs from 'fs';
import path from 'path';

// Default audio filenames if no files are found in the directory
export const DEFAULT_AUDIO_FILES = [
  // Cat sounds
  'cat_meow1.mp3',
  'cat_meow2.mp3',
  'cat_meow3.mp3',
  'cat_purr.mp3',
  'cat_hiss.mp3',
  'cat_yowl.mp3',
  
  // Dog sounds
  'dog_bark1.mp3',
  'dog_bark2.mp3',
  'dog_whine.mp3',
  'dog_pant.mp3',
  'dog_growl.mp3',
  'dog_howl.mp3',
  
  // Fox sounds
  'fox_bark.mp3',
  'fox_scream.mp3',
  'fox_yip.mp3',
  'fox_howl.mp3',
  'fox_chirp.mp3',
  
  // Robot sounds
  'robot_beep.mp3',
  'robot_whir.mp3',
  'robot_startup.mp3',
  'robot_shutdown.mp3',
  'robot_error.mp3',
  'robot_process.mp3',
];

// Gather audio files from the directory
export const CAT_AUDIO_FILES = gatherAudioFiles(config.audioFilesDir);
console.log(`Found ${CAT_AUDIO_FILES.length} audio files in ${config.audioFilesDir}`);

/**
 * Gather all audio files from a directory
 */
function gatherAudioFiles(audioPath: string): string[] {
  try {
    // Read all files in the audio directory
    if (fs.existsSync(audioPath)) {
      const files = fs.readdirSync(audioPath);
      const audioFiles = files.filter((file) => {
        const ext = file.split('.').pop()?.toLowerCase();
        return ext === 'wav' || ext === 'mp3' || ext === 'ogg';
      });
      
      if (audioFiles.length > 0) {
        return audioFiles;
      }
    }
  } catch (error) {
    console.warn(`Failed to read audio directory ${audioPath}:`, error);
  }
  
  // Return default audio files if none found
  console.warn('No audio files found, using default filenames. Please add audio files to the audio directory.');
  return DEFAULT_AUDIO_FILES;
}

/**
 * Generate sample audio files with README
 * This is useful for helping users set up the audio files
 */
export function generateSampleAudioInfo(directory: string): void {
  try {
    // Create directory if it doesn't exist
    if (!fs.existsSync(directory)) {
      fs.mkdirSync(directory, { recursive: true });
    }
    
    // Create a README file explaining the audio files
    const readmePath = path.join(directory, 'README.txt');
    const readmeContent = `Audio Files for the Discord Bot

This directory should contain audio files for different themes.
Naming convention: theme_sound.mp3 (e.g., cat_meow1.mp3, dog_bark1.mp3)

Recommended files for each theme:

CAT THEME:
- cat_meow1.mp3
- cat_meow2.mp3
- cat_meow3.mp3
- cat_purr.mp3
- cat_hiss.mp3
- cat_yowl.mp3

DOG THEME:
- dog_bark1.mp3
- dog_bark2.mp3
- dog_whine.mp3
- dog_pant.mp3
- dog_growl.mp3
- dog_howl.mp3

FOX THEME:
- fox_bark.mp3
- fox_scream.mp3
- fox_yip.mp3
- fox_howl.mp3
- fox_chirp.mp3

ROBOT THEME:
- robot_beep.mp3
- robot_whir.mp3
- robot_startup.mp3
- robot_shutdown.mp3
- robot_error.mp3
- robot_process.mp3

You can find free animal sound effects on sites like:
- Freesound.org
- SoundBible.com
- ZapSplat.com
`;
    
    fs.writeFileSync(readmePath, readmeContent);
    console.log(`Created audio README at ${readmePath}`);
  } catch (error) {
    console.error('Error creating sample audio info:', error);
  }
}
