import { REST, Routes } from 'discord.js';
import { commands } from '../commands';
import { config } from '../config/config';

/**
 * Deploy slash commands to Discord
 */
export async function deployCommands(): Promise<void> {
  if (!config.token) {
    throw new Error('Bot token not found in .env file');
  }

  const rest = new REST({ version: '10' }).setToken(config.token);
  
  try {
    console.log('Started refreshing application (/) commands...');
    
    // Extract command data
    const commandData = commands.map(command => command.data.toJSON());
    
    // Register commands globally
    await rest.put(
      Routes.applicationCommands(process.env.APPLICATION_ID || ''),
      { body: commandData }
    );
    
    console.log('Successfully reloaded application (/) commands!');
  } catch (error) {
    console.error('Error deploying commands:', error);
  }
}
